@@ -94,9 +94,11 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
     ```
     """
 
-    # we use dataclass fields in order to conveniently know what attributes are available
-    model: models.Model | models.KnownModelName | None
-    """The default model configured for this agent."""
+    model: models.Model | models.KnownModelName | str | None
+    """The default model configured for this agent.
+
+    We allow str here since the actual list of allowed models changes frequently.
+    """
 
     name: str | None
     """The name of the agent, used for logging.
@@ -142,7 +144,7 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
 
     def __init__(
         self,
-        model: models.Model | models.KnownModelName | None = None,
+        model: models.Model | models.KnownModelName | str | None = None,
         *,
         result_type: type[ResultDataT] = str,
         system_prompt: str | Sequence[str] = (),
@@ -163,7 +165,7 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
 
         Args:
             model: The default model to use for this agent, if not provide,
-                you must provide the model when calling it.
+                you must provide the model when calling it. We allow str here since the actual list of allowed models changes frequently.
             result_type: The type of the result data, used to validate the result data, defaults to `str`.
             system_prompt: Static system prompts to use for this agent, you can also register system
                 prompts via a function with [`system_prompt`][pydantic_ai.Agent.system_prompt].
@@ -212,16 +214,16 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
 
         self._result_tool_name = result_tool_name
         self._result_tool_description = result_tool_description
-        self._result_schema: _result.ResultSchema[ResultDataT] | None = _result.ResultSchema[result_type].build(
+        self._result_schema = _result.ResultSchema[result_type].build(
             result_type, result_tool_name, result_tool_description
         )
-        self._result_validators: list[_result.ResultValidator[AgentDepsT, ResultDataT]] = []
+        self._result_validators = []
 
         self._system_prompts = (system_prompt,) if isinstance(system_prompt, str) else tuple(system_prompt)
-        self._system_prompt_functions: list[_system_prompt.SystemPromptRunner[AgentDepsT]] = []
-        self._system_prompt_dynamic_functions: dict[str, _system_prompt.SystemPromptRunner[AgentDepsT]] = {}
+        self._system_prompt_functions = []
+        self._system_prompt_dynamic_functions = {}
 
-        self._function_tools: dict[str, Tool[AgentDepsT]] = {}
+        self._function_tools = {}
 
         self._default_retries = retries
         self._max_result_retries = result_retries if result_retries is not None else retries
@@ -244,7 +246,7 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
         *,
         result_type: None = None,
         message_history: list[_messages.ModelMessage] | None = None,
-        model: models.Model | models.KnownModelName | None = None,
+        model: models.Model | models.KnownModelName | str | None = None,
         deps: AgentDepsT = None,
         model_settings: ModelSettings | None = None,
         usage_limits: _usage.UsageLimits | None = None,
@@ -259,7 +261,7 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
         *,
         result_type: type[RunResultDataT],
         message_history: list[_messages.ModelMessage] | None = None,
-        model: models.Model | models.KnownModelName | None = None,
+        model: models.Model | models.KnownModelName | str | None = None,
         deps: AgentDepsT = None,
         model_settings: ModelSettings | None = None,
         usage_limits: _usage.UsageLimits | None = None,
@@ -273,7 +275,7 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
         *,
         result_type: type[RunResultDataT] | None = None,
         message_history: list[_messages.ModelMessage] | None = None,
-        model: models.Model | models.KnownModelName | None = None,
+        model: models.Model | models.KnownModelName | str | None = None,
         deps: AgentDepsT = None,
         model_settings: ModelSettings | None = None,
         usage_limits: _usage.UsageLimits | None = None,
@@ -327,8 +329,8 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
             async for _ in agent_run:
                 pass
 
-        assert (final_result := agent_run.result) is not None, 'The graph run did not finish properly'
-        return final_result
+        assert agent_run.result is not None, 'The graph run did not finish properly'
+        return agent_run.result
 
     @asynccontextmanager
     async def iter(
@@ -337,7 +339,7 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
         *,
         result_type: type[RunResultDataT] | None = None,
         message_history: list[_messages.ModelMessage] | None = None,
-        model: models.Model | models.KnownModelName | None = None,
+        model: models.Model | models.KnownModelName | str | None = None,
         deps: AgentDepsT = None,
         model_settings: ModelSettings | None = None,
         usage_limits: _usage.UsageLimits | None = None,
@@ -498,7 +500,7 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
         user_prompt: str | Sequence[_messages.UserContent],
         *,
         message_history: list[_messages.ModelMessage] | None = None,
-        model: models.Model | models.KnownModelName | None = None,
+        model: models.Model | models.KnownModelName | str | None = None,
         deps: AgentDepsT = None,
         model_settings: ModelSettings | None = None,
         usage_limits: _usage.UsageLimits | None = None,
@@ -513,7 +515,7 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
         *,
         result_type: type[RunResultDataT] | None,
         message_history: list[_messages.ModelMessage] | None = None,
-        model: models.Model | models.KnownModelName | None = None,
+        model: models.Model | models.KnownModelName | str | None = None,
         deps: AgentDepsT = None,
         model_settings: ModelSettings | None = None,
         usage_limits: _usage.UsageLimits | None = None,
@@ -527,7 +529,7 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
         *,
         result_type: type[RunResultDataT] | None = None,
         message_history: list[_messages.ModelMessage] | None = None,
-        model: models.Model | models.KnownModelName | None = None,
+        model: models.Model | models.KnownModelName | str | None = None,
         deps: AgentDepsT = None,
         model_settings: ModelSettings | None = None,
         usage_limits: _usage.UsageLimits | None = None,
@@ -588,7 +590,7 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
         *,
         result_type: None = None,
         message_history: list[_messages.ModelMessage] | None = None,
-        model: models.Model | models.KnownModelName | None = None,
+        model: models.Model | models.KnownModelName | str | None = None,
         deps: AgentDepsT = None,
         model_settings: ModelSettings | None = None,
         usage_limits: _usage.UsageLimits | None = None,
@@ -603,7 +605,7 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
         *,
         result_type: type[RunResultDataT],
         message_history: list[_messages.ModelMessage] | None = None,
-        model: models.Model | models.KnownModelName | None = None,
+        model: models.Model | models.KnownModelName | str | None = None,
         deps: AgentDepsT = None,
         model_settings: ModelSettings | None = None,
         usage_limits: _usage.UsageLimits | None = None,
@@ -618,7 +620,7 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
         *,
         result_type: type[RunResultDataT] | None = None,
         message_history: list[_messages.ModelMessage] | None = None,
-        model: models.Model | models.KnownModelName | None = None,
+        model: models.Model | models.KnownModelName | str | None = None,
         deps: AgentDepsT = None,
         model_settings: ModelSettings | None = None,
         usage_limits: _usage.UsageLimits | None = None,
@@ -757,12 +759,12 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
         self,
         *,
         deps: AgentDepsT | _utils.Unset = _utils.UNSET,
-        model: models.Model | models.KnownModelName | _utils.Unset = _utils.UNSET,
+        model: models.Model | models.KnownModelName | str | _utils.Unset = _utils.UNSET,
     ) -> Iterator[None]:
         """Context manager to temporarily override agent dependencies and model.
 
         This is particularly useful when testing.
-        You can find an example of this [here](../testing-evals.md#overriding-model-via-pytest-fixtures).
+        You can find an example of this [here](../testing.md#overriding-model-via-pytest-fixtures).
 
         Args:
             deps: The dependencies to use instead of the dependencies passed to the agent run.
@@ -774,11 +776,9 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
         else:
             override_deps_before = _utils.UNSET
 
-        # noinspection PyTypeChecker
         if _utils.is_set(model):
             override_model_before = self._override_model
-            # noinspection PyTypeChecker
-            self._override_model = _utils.Some(models.infer_model(model))  # pyright: ignore[reportArgumentType]
+            self._override_model = _utils.Some(models.infer_model(model))
         else:
             override_model_before = _utils.UNSET
 
@@ -1154,7 +1154,7 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
 
         self._function_tools[tool.name] = tool
 
-    def _get_model(self, model: models.Model | models.KnownModelName | None) -> models.Model:
+    def _get_model(self, model: models.Model | models.KnownModelName | str | None) -> models.Model:
         """Create a model configured for this agent.
 
         Args:
@@ -1168,7 +1168,7 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
             # we don't want `override()` to cover up errors from the model not being defined, hence this check
             if model is None and self.model is None:
                 raise exceptions.UserError(
-                    '`model` must be set either when creating the agent or when calling it. '
+                    '`model` must either be set on the agent or included when calling it. '
                     '(Even when `override(model=...)` is customizing the model that will actually be called)'
                 )
             model_ = some_model.value
@@ -1178,7 +1178,7 @@ class Agent(Generic[AgentDepsT, ResultDataT]):
             # noinspection PyTypeChecker
             model_ = self.model = models.infer_model(self.model)
         else:
-            raise exceptions.UserError('`model` must be set either when creating the agent or when calling it.')
+            raise exceptions.UserError('`model` must either be set on the agent or included when calling it.')
 
         instrument = self.instrument
         if instrument is None:
