@@ -43,34 +43,51 @@ except ImportError as _import_error:
         'you can use the `groq` optional group — `pip install "pydantic-ai-slim[groq]"`'
     ) from _import_error
 
-
-LatestGroqModelNames = Literal[
+ProductionGroqModelNames = Literal[
+    'distil-whisper-large-v3-en',
+    'gemma2-9b-it',
     'llama-3.3-70b-versatile',
-    'llama-3.3-70b-specdec',
     'llama-3.1-8b-instant',
+    'llama-guard-3-8b',
+    'llama3-70b-8192',
+    'llama3-8b-8192',
+    'whisper-large-v3',
+    'whisper-large-v3-turbo',
+]
+"""Production Groq models from <https://console.groq.com/docs/models#production-models>."""
+
+PreviewGroqModelNames = Literal[
+    'playai-tts',
+    'playai-tts-arabic',
+    'qwen-qwq-32b',
+    'mistral-saba-24b',
+    'qwen-2.5-coder-32b',
+    'qwen-2.5-32b',
+    'deepseek-r1-distill-qwen-32b',
+    'deepseek-r1-distill-llama-70b',
+    'llama-3.3-70b-specdec',
     'llama-3.2-1b-preview',
     'llama-3.2-3b-preview',
     'llama-3.2-11b-vision-preview',
     'llama-3.2-90b-vision-preview',
-    'llama3-70b-8192',
-    'llama3-8b-8192',
-    'mixtral-8x7b-32768',
-    'gemma2-9b-it',
 ]
-"""Latest Groq models."""
+"""Preview Groq models from <https://console.groq.com/docs/models#preview-models>."""
 
-GroqModelName = Union[str, LatestGroqModelNames]
-"""
-Possible Groq model names.
+GroqModelName = Union[str, ProductionGroqModelNames, PreviewGroqModelNames]
+"""Possible Groq model names.
 
-Since Groq supports a variety of date-stamped models, we explicitly list the latest models but
-allow any name in the type hints.
-See [the Groq docs](https://console.groq.com/docs/models) for a full list.
+Since Groq supports a variety of models and the list changes frequencly, we explicitly list the named models as of 2025-03-31
+but allow any name in the type hints.
+
+See <https://console.groq.com/docs/models> for an up to date date list of models and more details.
 """
 
 
 class GroqModelSettings(ModelSettings):
-    """Settings used for a Groq model request."""
+    """Settings used for a Groq model request.
+
+    ALL FIELDS MUST BE `groq_` PREFIXED SO YOU CAN MERGE THEM WITH OTHER MODELS.
+    """
 
     # This class is a placeholder for any future groq-specific settings
 
