@@ -2,10 +2,12 @@ from __future__ import annotations as _annotations
 
 import dataclasses
 import inspect
+import json
 from collections.abc import Awaitable, Sequence
 from dataclasses import dataclass, field
 from typing import TYPE_CHECKING, Any, Callable, Generic, Literal, Union, cast
 
+from opentelemetry.trace import Tracer
 from pydantic import ValidationError
 from pydantic.json_schema import GenerateJsonSchema, JsonSchemaValue
 from pydantic_core import SchemaValidator, core_schema
@@ -147,8 +149,8 @@ class GenerateToolJsonSchema(GenerateJsonSchema):
     def typed_dict_schema(self, schema: core_schema.TypedDictSchema) -> JsonSchemaValue:
         s = super().typed_dict_schema(schema)
         total = schema.get('total')
-        if total is not None:
-            s['additionalProperties'] = not total
+        if 'additionalProperties' not in s and (total is True or total is None):
+            s['additionalProperties'] = False
         return s
 
     def _named_required_fields_schema(self, named_required_fields: Sequence[tuple[str, bool, Any]]) -> JsonSchemaValue:
@@ -286,9 +288,38 @@ class Tool(Generic[AgentDepsT]):
             return tool_def
 
     async def run(
+        self, message: _messages.ToolCallPart, run_context: RunContext[AgentDepsT], tracer: Tracer
+    ) -> _messages.ToolReturnPart | _messages.RetryPromptPart:
+        """Run the tool function asynchronously.
+
+        This method wraps `_run` in an OpenTelemetry span.
+
+        See <https://opentelemetry.io/docs/specs/semconv/gen-ai/gen-ai-spans/#execute-tool-span>.
+        """
+        span_attributes = {
+            'gen_ai.tool.name': self.name,
+            # NOTE: this means `gen_ai.tool.call.id` will be included even if it was generated by pydantic-ai
+            'gen_ai.tool.call.id': message.tool_call_id,
+            'tool_arguments': message.args_as_json_str(),
+            'logfire.msg': f'running tool: {self.name}',
+            # add the JSON schema so these attributes are formatted nicely in Logfire
+            'logfire.json_schema': json.dumps(
+                {
+                    'type': 'object',
+                    'properties': {
+                        'tool_arguments': {'type': 'object'},
+                        'gen_ai.tool.name': {},
+                        'gen_ai.tool.call.id': {},
+                    },
+                }
+            ),
+        }
+        with tracer.start_as_current_span('running tool', attributes=span_attributes):
+            return await self._run(message, run_context)
+
+    async def _run(
         self, message: _messages.ToolCallPart, run_context: RunContext[AgentDepsT]
     ) -> _messages.ToolReturnPart | _messages.RetryPromptPart:
-        """Run the tool function asynchronously."""
         try:
             if isinstance(message.args, str):
                 args_dict = self._validator.validate_json(message.args)
